datablock ItemData(mixashootItem)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system

	 // Basic Item Properties
	shapeFile = "./shapes/5000.dts";
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Amazing Mixashoot-MGL5000"; // this gun contains a manly gun likeness of 5000
	iconName = "./5000";
	doColorShift = true;
	colorShiftColor = "1.0 1.0 1.0 1.0";

	 // Dynamic properties defined by the scripts
	image = mixashootImage;
	canDrop = true;
	
	// BATTLE ROTATIONS STUFF
	BattleRotators = 1;
	br_insane = 1;
	br_op = 1;
};

datablock ShapeBaseImageData(mixashootImage)
{
	// Basic Item properties
	shapeFile = "./shapes/5000.dts";
	emap = true;

	// Specify mount point & offset for 3rd person, and eye offset
	// for first person rendering.
	mountPoint = 0;
	offset = "0 0 0";
	eyeOffset = 0; //"0.7 1.2 -0.5";
	rotation = eulerToMatrix( "0 0 0" );

	// When firing from a point offset from the eye, muzzle correction
	// will adjust the muzzle vector to point to the eye LOS point.
	// Since this weapon doesn't actually fire from the muzzle point,
	// we need to turn this off.  
	correctMuzzleVector = true;

	// Add the WeaponImage namespace as a parent, WeaponImage namespace
	// provides some hooks into the inventory system.
	className = "WeaponImage";

	// Projectile && Ammo.
	item = mixashootItem;
	ammo = " ";
	projectile = gunProjectile;
	projectileType = Projectile;

	casing = gunShellDebris;
	shellExitDir        = "1.0 -1.3 1.0";
	shellExitOffset     = "0 0 0";
	shellExitVariance   = 15.0;	
	shellVelocity       = 7.0;

	//melee particles shoot from eye node for consistancy
	melee = false;
	//raise your arm up or not
	armReady = true;

	doColorShift = true;
	colorShiftColor = mixashootItem.colorShiftColor;//"0.400 0.196 0 1.000";

	//casing = " ";

	// Images have a state system which controls how the animations
	// are run, which sounds are played, script callbacks, etc. This
	// state system is downloaded to the client so that clients can
	// predict state changes and animate accordingly.  The following
	// system supports basic ready->fire->reload transitions as
	// well as a no-ammo->dryfire idle state.

	// Initial start up state
	stateName[0]                     = "Activate";
	stateTimeoutValue[0]             = 0.15;
	stateTransitionOnTimeout[0]       = "Ready";
	stateSound[0]					= weaponSwitchSound;

	stateName[1]                     = "Ready";
	stateTransitionOnTriggerDown[1]  = "Fire";
	stateAllowImageChange[1]         = true;
	stateSequence[1]	= "Ready";

	stateName[2]                    = "Fire";
	stateTransitionOnTimeout[2]     = "Smoke";
	stateTimeoutValue[2]            = 0.05;
	stateFire[2]                    = true;
	stateAllowImageChange[2]        = false;
	stateSequence[2]                = "Fire";
	stateScript[2]                  = "onFire";
	stateWaitForTimeout[2]			= true;
	stateEmitter[2]					= mixashootTetrakaikimboFlashEmitter;
	stateEmitterTime[2]				= 0.05;
	stateEmitterNode[2]				= "muzzleNode";
	//stateSound[2]					= gunShot1Sound;
	stateEjectShell[2]       = true;

	stateName[3] = "Smoke";
	stateEmitter[3]					= gunSmokeEmitter;
	stateEmitterTime[3]				= 0.05;
	stateEmitterNode[3]				= "muzzleNode";
	stateTimeoutValue[3]            = 0.001;
	stateTransitionOnTimeout[3]     = "Reload";

	stateName[4]			= "Reload";
	stateSequence[4]                = "Reload";
	stateTransitionOnTriggerUp[4]     = "Ready";
	stateSequence[4]	= "Ready";
};

function mixashootImage::onFire(%this,%obj,%slot)
{
	if(%obj.getDamagePercent() < 1.0)
	{
		%obj.playThread(2, shiftAway);
		
		%ran = getRandom(1, mixashootProjectiles.getCount())-1;
		%projectile = mixashootProjectiles.getObject(%ran);
		
		if(%projectile.muzzleVelocity < 100)
			%muzzleVelocity = 150;
		else
			%muzzleVelocity = %projectile.muzzleVelocity;
		
		serverPlay3D(mixashootPistolFire, %obj.getPosition());
		
		%spread = 0.0001;
		
		%vector = %obj.getMuzzleVector(%slot);
		%objectVelocity = %obj.getVelocity();
		%vector1 = VectorScale(%vector, %muzzleVelocity);
		%vector2 = VectorScale(%objectVelocity, %projectile.velInheritFactor);
		%velocity = VectorAdd(%vector1,%vector2);
		%x = (getRandom() - 0.5) * 10 * 3.1415926 * %spread;
		%y = (getRandom() - 0.5) * 10 * 3.1415926 * %spread;
		%z = (getRandom() - 0.5) * 10 * 3.1415926 * %spread;
		%mat = MatrixCreateFromEuler(%x @ " " @ %y @ " " @ %z);
		%velocity = MatrixMulVector(%mat, %velocity);
		
		// for whatever fucking reason it doesn't want to fire from muzzlePoint(0)
		// so i'm going to have to do some fancy math to fix it
		%pos = vectorAdd(%obj.getMuzzlePoint(%slot), vectorScale("0 0 1", 0.27));
		%pos = vectorAdd(%pos, vectorScale(%obj.getMuzzleVector(%slot), 0.70));
		
		%p = new Projectile()
		{
			datablock = %projectile;
			initialVelocity = %velocity;
			initialPosition = %pos;
			client = %obj.client;
			sourceObject = %obj;
			sourceSlot = %slot;
		};
		MissionCleanup.add(%p);
	}
	
	return %p;
}